'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _underscore = require('underscore');

var _underscore2 = _interopRequireDefault(_underscore);

var _queryString = require('query-string');

var _queryString2 = _interopRequireDefault(_queryString);

var _cookie = require('../managers/cookie');

var _cookie2 = _interopRequireDefault(_cookie);

var _auth = require('../managers/auth');

var _auth2 = _interopRequireDefault(_auth);

var _axios = require('../managers/axios');

var _axios2 = _interopRequireDefault(_axios);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var BaseApi = function () {
    function BaseApi() {
        _classCallCheck(this, BaseApi);

        this._METHOD_GET = 'get';
        this._METHOD_POST = 'post';
        this._METHOD_PATCH = 'patch';
        this._METHOD_DELETE = 'delete';
        // this.interceptor()
    }

    /**
     * Get api path
     * @return {string}
     */


    _createClass(BaseApi, [{
        key: 'getApiPath',
        value: function getApiPath() {}

        /** Assign an object */

    }, {
        key: 'getDataObject',
        value: function getDataObject() {}

        /**
         * Get record list
         * @param {object} params
         * @return {Promise}
         */

    }, {
        key: 'getRecordsList',
        value: function getRecordsList(params) {
            var additionalParams = params ? '?' + _queryString2.default.stringify(params) : '';
            var _this = this;
            return new Promise(function (resolve, reject) {
                _this.makeApiRequest(_this._METHOD_GET, _this.getApiPath() + additionalParams).then(function (result) {
                    var newArray = [];
                    if (result.total !== 0) {
                        var iThis = _this;
                        _underscore2.default.map(result.data.records, function (record) {
                            newArray.push(iThis.getDataObject().parseDataFromResourceServer(record));
                        });
                        result.data.records = newArray;
                        resolve(result.data);
                    } else {
                        resolve(result);
                    }
                }).catch(function (error) {
                    reject(error);
                });
            });
        }

        /**
         * Get single record
         * @param {number} recordId
         * @return {Promise}
         */

    }, {
        key: 'getSingleRecord',
        value: function getSingleRecord(recordId) {
            var _this = this;
            return new Promise(function (resolve, reject) {
                _this.makeApiRequest(_this._METHOD_GET, _this.buildUrlForSingleRecord(recordId), []).then(function (result) {
                    resolve(_this.getDataObject().parseDataFromResourceServer(result.data));
                }).catch(function (error) {
                    reject(error);
                });
            });
        }

        /**
         * Create record
         * @param {object} data
         * @return {Promise}
         */

    }, {
        key: 'createRecord',
        value: function createRecord(data) {
            var _this = this;
            return new Promise(function (resolve, reject) {
                _this.makeApiRequest(_this._METHOD_POST, _this.getApiPath(), data).then(function (result) {
                    resolve(_this.getDataObject().parseDataFromResourceServer(result.data));
                }).catch(function (error) {
                    reject(error);
                });
            });
        }

        /**
         * Update record
         * @param {number} recordId
         * @param {object} data
         * @return {Promise}
         */

    }, {
        key: 'updateRecord',
        value: function updateRecord(recordId, data) {
            var _this = this;
            return new Promise(function (resolve, reject) {
                _this.makeApiRequest(_this._METHOD_PATCH, _this.buildUrlForSingleRecord(recordId), data).then(function (result) {
                    resolve(_this.getDataObject().parseDataFromResourceServer(result.data));
                }).catch(function (error) {
                    reject(error);
                });
            });
        }

        /**
         * Delete record
         * @param {number} recordId
         * @return {Promise}
         */

    }, {
        key: 'deleteRecord',
        value: function deleteRecord(recordId) {
            return this.makeApiRequest(this._METHOD_DELETE, this.buildUrlForSingleRecord(recordId), []);
        }

        /**
         * Build url for single record
         * @param {number} recordId
         * @return {string}
         */

    }, {
        key: 'buildUrlForSingleRecord',
        value: function buildUrlForSingleRecord(recordId) {
            return this.getApiPath() + '/' + recordId;
        }

        /**
         * Make api request
         * @param {string} method
         * @param {string} url
         * @param {array} data
         * @return {Promise}
         */

    }, {
        key: 'makeApiRequest',
        value: function makeApiRequest(method, url, data) {
            return this.callApi(method, 'api/' + url, data);
        }
    }, {
        key: 'interceptor',
        value: function interceptor() {
            // request happnas multiple times
            _axios2.default.interceptors.response.use(undefined, function (err) {
                return new Promise(function (resolve, reject) {
                    if (err.response.status === 401 && err.config && !err.config.__isRetryRequest) {
                        _auth2.default.refreshToken().then(function (response) {
                            _cookie2.default.setToken(response.data);
                            err.config.__isRetryRequest = true;
                            err.config.headers.Authorization = 'Bearer ' + _cookie2.default.getCurrentToken();
                            // err.config.headers.Authorization = 'Bearer ' + response.data.access_token
                            (0, _axios2.default)(err.config).then(resolve, reject);
                        }).catch(function (error) {
                            console.log('Refresh login error: ', error);
                            reject(error);
                        });
                    }
                    throw err;
                });
            });
            /*axios.interceptors.response.use(function (response) {
                console.log('response')
                console.log(response)
                // Do something with response data
                return response;
            }, function (error) {
                console.log('error')
                console.log(error)
                if (err.response.status === 401 && err.response.config && !err.response.config.__isRetryRequest) {
                    // get url request from response or request
                }
                // Do something with response error
                 // ?????
                // return Promise.resolve(refreshToken().then(_ => Vue.http(req)))
                return Promise.reject(error);
            });*/
        }

        /**
         * Call api
         * @param {string} method
         * @param {string} url
         * @param {array} data
         * @return {Promise}
         */

    }, {
        key: 'callApi',
        value: function callApi(method, url, data) {
            var config = {
                method: method,
                url: url,
                data: data,
                headers: {}
                // config.headers['Authorization'] = 'Bearer YWYxZTYwYWRkMjE3YjFkOWE1N2UzYjZlNzc2MmJjNmRjMDJlMDAxYzBiMjA4N2VlMmJmYTg5MDkxYWNhMTIwMg'
            };if (_cookie2.default.getCurrentToken()) {
                config.headers['Authorization'] = 'Bearer ' + _cookie2.default.getCurrentToken();
            }
            return _axios2.default.request(config);
        }
    }]);

    return BaseApi;
}();

exports.default = BaseApi;